From: Samuel Thibault <samuel.thibault@ens-lyon.org>

We need to keep  proc_setowner_request for backward compatibility
Better call reauth complete proc_reauthenticate_something for coherency.

Index: hurd-debian/hurd/process_request.defs
===================================================================
--- hurd-debian.orig/hurd/process_request.defs
+++ hurd-debian/hurd/process_request.defs
@@ -87,7 +87,7 @@ simpleroutine proc_register_version_requ
 
 /* Change the current authentication of the process.  The user should
    follow this call with a call to auth_user_authenticate, and then a
-   call to proc_complete_reauthentication on the port passed back
+   call to proc_reauthenticate_complete on the port passed back
    through the auth server, which becomes the new port for this process.
    The old process port is destroyed.  */
 simpleroutine proc_reauthenticate_request (
@@ -125,7 +125,12 @@ simpleroutine proc_reassign_request (
 	ureplyport reply: reply_port_t;
 	newtask: task_t);
 
-skip;  /* Was proc_setowner */
+/* Deprecated; definition kept for compatibility. */
+simpleroutine proc_setowner_request (
+	process: process_t;
+	ureplyport reply: reply_port_t;
+	owner: uid_t;
+	clear: int);
 
 /* Get the process ID and the parent process ID, also find out if we
    are orphaned.  */
@@ -422,4 +427,4 @@ skip; /* proc_get_entry */
 skip; /* proc_waitid */
 
 skip; /* proc_reauthenticate_reassign */
-skip; /* proc_complete_reauthentication */
+skip; /* proc_reauthenticate_complete */
Index: hurd-debian/exec/exec.c
===================================================================
--- hurd-debian.orig/exec/exec.c
+++ hurd-debian/exec/exec.c
@@ -1406,7 +1406,7 @@ do_exec (file_t file,
       if (e.error)
         goto out;
 
-      e.error = proc_complete_reauthentication (newproc);
+      e.error = proc_reauthenticate_complete (newproc);
       if (e.error)
         {
           mach_port_deallocate (mach_task_self (), newproc);
Index: hurd-debian/hurd/process.defs
===================================================================
--- hurd-debian.orig/hurd/process.defs
+++ hurd-debian/hurd/process.defs
@@ -87,7 +87,7 @@ routine proc_register_version (
 
 /* Change the current authentication of the process.  The user should
    follow this call with a call to auth_user_authenticate, and then a
-   call to proc_complete_reauthentication on the port passed back
+   call to proc_reauthenticate_complete on the port passed back
    through the auth server, which becomes the new port for this process.
    The old process port is destroyed.  */
 simpleroutine proc_reauthenticate (
@@ -453,7 +453,7 @@ routine proc_waitid (
 
 /* Change the current authentication of the process and assign a different
    task to it, atomically.  The user should follow this call with a call to
-   auth_user_authenticate, and then a call to proc_complete_reauthentication
+   auth_user_authenticate, and then a call to proc_reauthenticate_complete
    on the port passed back through the auth server, which becomes the new
    port for this process.  The old process port is destroyed.  */
 simpleroutine proc_reauthenticate_reassign (
@@ -464,5 +464,5 @@ simpleroutine proc_reauthenticate_reassi
 /* Complete reauthentication started with proc_reauthenticate or
    proc_reauthenticate_reassign.  The process port must be the port
    that the user has received from auth_user_authenticate call.  */
-simpleroutine proc_complete_reauthentication (
+simpleroutine proc_reauthenticate_complete (
 	process: process_t);
Index: hurd-debian/hurd/process_reply.defs
===================================================================
--- hurd-debian.orig/hurd/process_reply.defs
+++ hurd-debian/hurd/process_reply.defs
@@ -204,4 +204,4 @@ skip; /* proc_get_entry */
 skip; /* proc_waitid */
 
 skip; /* proc_reauthenticate_reassign */
-skip; /* proc_complete_reauthentication */
+skip; /* proc_reauthenticate_complete */
Index: hurd-debian/libfshelp/start-translator-long.c
===================================================================
--- hurd-debian.orig/libfshelp/start-translator-long.c
+++ hurd-debian/libfshelp/start-translator-long.c
@@ -307,7 +307,7 @@ fshelp_start_translator_long (fshelp_ope
       if (err)
         goto lose_task;
 
-      err = proc_complete_reauthentication (newport);
+      err = proc_reauthenticate_complete (newport);
       if (err)
         {
           mach_port_deallocate (mach_task_self (), newport);
Index: hurd-debian/libshouldbeinlibc/exec-reauth.c
===================================================================
--- hurd-debian.orig/libshouldbeinlibc/exec-reauth.c
+++ hurd-debian/libshouldbeinlibc/exec-reauth.c
@@ -68,7 +68,7 @@ exec_reauth (auth_t auth, int secure, in
 
           if (isproc)
             {
-              err = proc_complete_reauthentication (newport);
+              err = proc_reauthenticate_complete (newport);
               if (err)
                 {
                   mach_port_deallocate (mach_task_self (), newport);
Index: hurd-debian/proc/mgt.c
===================================================================
--- hurd-debian.orig/proc/mgt.c
+++ hurd-debian/proc/mgt.c
@@ -119,7 +119,7 @@ S_proc_reauthenticate (struct proc *p, m
 
   new_proc_port = mach_reply_port ();
   /* Ask to be told if the new port dies.  We receive the notification
-     on the same port, and as it's not a proc_complete_reauthentication ()
+     on the same port, and as it's not a proc_reauthenticate_complete ()
      call, consider it an error.  */
   err = mach_port_request_notification (mach_task_self (), new_proc_port,
                                         MACH_NOTIFY_NO_SENDERS, 1,
@@ -142,7 +142,7 @@ S_proc_reauthenticate (struct proc *p, m
                                     &aux_gids, &naux_gids);
   while (err == EINTR);
 
   /* Wait for a proc_complete_reauthentication () call
      on the new port before proceeding.  */
   if (!err)
     {
@@ -157,7 +157,7 @@ S_proc_reauthenticate (struct proc *p, m
     goto out;
 
   /* Check if what we have received was indeed a
-     proc_complete_reauthentication () call.  */
+     proc_reauthenticate_complete () call.  */
   if (msg.msgh_id != 24064)
     err = EINVAL;
   mach_msg_destroy (&msg);
@@ -379,7 +379,7 @@ S_proc_reauthenticate_reassign (struct p
 
   new_proc_port = mach_reply_port ();
   /* Ask to be told if the new port dies.  We receive the notification
-     on the same port, and as it's not a proc_complete_reauthentication ()
+     on the same port, and as it's not a proc_reauthenticate_complete ()
      call, consider it an error.  */
   err = mach_port_request_notification (mach_task_self (), new_proc_port,
                                         MACH_NOTIFY_NO_SENDERS, 1,
@@ -407,7 +407,7 @@ S_proc_reauthenticate_reassign (struct p
                                     &aux_gids, &naux_gids);
   while (err == EINTR);
 
   /* Wait for a proc_complete_reauthentication () call
      on the new port before proceeding.  */
   if (!err)
     {
@@ -422,7 +422,7 @@ S_proc_reauthenticate_reassign (struct p
     goto out;
 
   /* Check if what we have received was indeed a
-     proc_complete_reauthentication () call.  */
+     proc_reauthenticate_complete () call.  */
   if (msg.msgh_id != 24064)
     err = EINVAL;
   mach_msg_destroy (&msg);
@@ -510,7 +510,7 @@ S_proc_setowner (struct proc *p,
 }
 
 kern_return_t
-S_proc_complete_reauthentication (struct proc *p)
+S_proc_reauthenticate_complete (struct proc *p)
 {
   /* Regular calls of this routine always fail.  */
   return EOPNOTSUPP;
@@ -142,7 +142,7 @@ S_proc_reauthenticate (struct proc *p, m
   while (err == EINTR);
 
-  /* Wait for a proc_complete_reauthentication () call
+  /* Wait for a proc_reauthenticate_complete () call
      on the new port before proceeding.  */
   if (!err)
@@ -407,7 +407,7 @@ S_proc_reauthenticate_reassign (struct p
   while (err == EINTR);
 
-  /* Wait for a proc_complete_reauthentication () call
+  /* Wait for a proc_reauthenticate_complete () call
      on the new port before proceeding.  */
   if (!err)
